import { WebElementFinder, WebElementListFinder } from "../../interface/WebElements";
export interface UntilElementCondition {
    visible: UntilElementCondition;
    enabled: UntilElementCondition;
    forAsLongAs(timeout: number): UntilElementCondition;
    waitFor(elements: WebElementFinder | WebElementListFinder): Promise<void>;
    readonly modifierFunc: LogicFunction<boolean>;
    readonly waiter: ElementCondition;
    readonly timeout: number;
    readonly conditionHelpText: string;
}
declare abstract class ElementCondition {
    abstract helpText: string;
    elementText: string;
    abstract isFulfilledFor(element: WebElementFinder | WebElementListFinder): () => Promise<boolean>;
}
export declare class VisibilityCheck extends ElementCondition {
    modifierFunc: (result: boolean) => boolean;
    helpText: string;
    constructor(modifierFunc: (result: boolean) => boolean, helpText?: string);
    isFulfilledFor(element: WebElementFinder | WebElementListFinder): () => Promise<boolean>;
}
export declare class EnabledCheck extends ElementCondition {
    modifierFunc: (result: boolean) => boolean;
    helpText: string;
    constructor(modifierFunc: (result: boolean) => boolean, helpText?: string);
    isFulfilledFor(element: WebElementFinder): () => Promise<boolean>;
}
declare type LogicFunction<T> = (param: T) => T;
export declare class UntilElement implements UntilElementCondition {
    modifierFunc: LogicFunction<boolean>;
    private _timeout;
    waiter: ElementCondition;
    private static readonly id;
    private static readonly negate;
    static get is(): UntilElement;
    static get isNot(): UntilElement;
    get visible(): UntilElementCondition;
    get enabled(): UntilElementCondition;
    private constructor();
    forAsLongAs(timeout: number): UntilElementCondition;
    get timeout(): number;
    get conditionHelpText(): string;
    toString(): string;
    waitFor(elements: WebElementFinder | WebElementListFinder): Promise<void>;
}
export {};
//# sourceMappingURL=ElementConditions.d.ts.map